"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CompassPipelineStorage = void 0;
const compass_user_data_1 = require("@mongodb-js/compass-user-data");
const pipeline_storage_schema_1 = require("./pipeline-storage-schema");
class CompassPipelineStorage {
    constructor(basePath) {
        this.userData = new compass_user_data_1.UserData(pipeline_storage_schema_1.PipelineSchema, {
            subdir: 'SavedPipelines',
            basePath,
        });
    }
    mergeStats(pipeline, stats) {
        return {
            ...pipeline,
            lastModified: new Date(stats.ctimeMs),
        };
    }
    async loadAll() {
        try {
            const { data } = await this.userData.readAllWithStats({
                ignoreErrors: false,
            });
            return data.map(([item, stats]) => {
                return this.mergeStats(item, stats);
            });
        }
        catch {
            return [];
        }
    }
    loadMany(predicate) {
        return this.loadAll().then((pipelines) => pipelines.filter(predicate));
    }
    async loadOne(id) {
        const [item, stats] = await this.userData.readOneWithStats(id);
        return this.mergeStats(item, stats);
    }
    async createOrUpdate(id, attributes) {
        const pipelineExists = Boolean(await this.userData.readOne(id, {
            ignoreErrors: true,
        }));
        return await (pipelineExists
            ? this.updateAttributes(id, attributes)
            : this.create(attributes));
    }
    async create(data) {
        await this.userData.write(data.id, {
            ...data,
            lastModified: Date.now(),
        });
        return await this.loadOne(data.id);
    }
    async updateAttributes(id, attributes) {
        await this.userData.write(id, {
            ...(await this.loadOne(id)),
            ...attributes,
            lastModified: Date.now(),
        });
        return await this.loadOne(id);
    }
    async delete(id) {
        await this.userData.delete(id);
    }
}
exports.CompassPipelineStorage = CompassPipelineStorage;
//# sourceMappingURL=compass-pipeline-storage.js.map